"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.spawn = spawn;

var _crossSpawn = _interopRequireDefault(require("cross-spawn"));

var _shellQuote = _interopRequireDefault(require("shell-quote"));

var _log = require("./log");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function spawn(command, {
  commandOptions = {
    stdio: "inherit"
  },
  exitOnComplete = false,
  exitOnError = true
} = {}) {
  (0, _log.logDebug)("Spawning command: %s", command);
  (0, _log.logDebug)("Command options: %j", commandOptions);
  (0, _log.logDebug)("Exit on complete: %j", exitOnComplete);
  (0, _log.logDebug)("Exit on error: %j", exitOnError);
  const commandParts = getCommandParts(command);
  (0, _log.logDebug)("Command parts: %j", commandParts);

  const response = _crossSpawn.default.sync(commandParts.command, commandParts.args, commandOptions);

  (0, _log.logDebug)("Response status: %j", response.status);

  if (shouldExit(exitOnComplete, exitOnError, response)) {
    (0, _log.logDebug)("shouldExit = true");
    process.exit(response.status); // eslint-disable-line unicorn/no-process-exit
  }

  return response;
}

function getCommandParts(commandIn) {
  const [command, ...args] = _shellQuote.default.parse(commandIn);

  return {
    command,
    args
  };
}

function shouldExit(exitOnComplete, exitOnError, response) {
  if (exitOnComplete) {
    return true;
  }

  return exitOnError && response.status !== 0;
}
//# sourceMappingURL=spawn.js.map