"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createExposedApp = createExposedApp;

var _asyncro = require("asyncro");

var _log = require("../common/log");

var _context = require("./context");

var _options = require("./options");

var _copyTemplate = require("./steps/copy-template/copy-template");

var _formatFiles = require("./steps/format-files");

var _git = require("./steps/git");

var _goodbye = require("./steps/goodbye");

var _installDependencies = require("./steps/install-dependencies");

var _setupSemanticRelease = require("./steps/setup-semantic-release");

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

function createExposedApp(_x) {
  return _createExposedApp.apply(this, arguments);
}

function _createExposedApp() {
  _createExposedApp = _asyncToGenerator(function* (options) {
    (0, _log.logDebug)("Options: %o", options);
    (0, _options.validateOptions)(options);
    const processedOptions = (0, _options.processUserOptions)(options);
    (0, _log.logDebug)("Processed options: %o", processedOptions);
    const context = (0, _context.createAppContext)(processedOptions);
    (0, _log.logDebug)("Context: %o", context);
    process.chdir(context.options.destinationPath);
    const stepsToExecute = [_git.executeStepGit, _copyTemplate.executeStepCopyTemplate, _installDependencies.executeStepInstallDependencies, _formatFiles.executeStepFormatFiles, _setupSemanticRelease.executeStepSetupSemanticRelease, _goodbye.executeStepGoodbye];
    yield executeSteps(stepsToExecute, context);
  });
  return _createExposedApp.apply(this, arguments);
}

function executeSteps(_x2, _x3) {
  return _executeSteps.apply(this, arguments);
}

function _executeSteps() {
  _executeSteps = _asyncToGenerator(function* (stepsToExecute, context) {
    return (0, _asyncro.reduce)(stepsToExecute, executeStep, context);
  });
  return _executeSteps.apply(this, arguments);
}

function executeStep(_x4, _x5) {
  return _executeStep.apply(this, arguments);
}

function _executeStep() {
  _executeStep = _asyncToGenerator(function* (context, stepToExecute) {
    (0, _log.logDebug)("Executing step: %s", stepToExecute.name);
    (0, _log.logDebug)("Step context: %o", context);
    const newContext = yield stepToExecute(context);
    return newContext;
  });
  return _executeStep.apply(this, arguments);
}
//# sourceMappingURL=create-exposed-app.js.map