"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.copy = copy;

var _recursiveCopy = _interopRequireDefault(require("recursive-copy"));

var _log = require("../../../common/log");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const templateSuffix = ".template";

function copy(sourcePath, destPath, viewData) {
  const recuriveCopyOptions = {
    overwrite: true,
    dot: true,
    rename: filePath => {
      const newDestPath = toDestinationPath(filePath, viewData);
      (0, _log.logDebug)("Copy %s to %s", filePath, newDestPath);
      return newDestPath;
    }
  };
  return (0, _recursiveCopy.default)(sourcePath, destPath, recuriveCopyOptions).on(_recursiveCopy.default.events.COPY_FILE_COMPLETE, onCopyComplete).on(_recursiveCopy.default.events.ERROR, onCopyError);
}

function toDestinationPath(templatePath, viewData) {
  const noSuffix = removeTemplateSuffix(templatePath);
  const withViewData = replaceFilePathWithViewData(noSuffix, viewData);
  return withViewData;
}

function removeTemplateSuffix(filePath) {
  return filePath.endsWith(templateSuffix) ? filePath.substr(0, filePath.length - templateSuffix.length) : filePath;
}

function replaceFilePathWithViewData(filePath, viewData) {
  return Object.entries(viewData).reduce((accfilePath, viewDataEntry) => {
    const [viewKey, viewValue] = viewDataEntry;
    return replaceFilePathWithViewParts(accfilePath, viewKey, viewValue);
  }, filePath);
}

function replaceFilePathWithViewParts(filePath, viewKey, viewValue) {
  if (!viewValue) {
    return filePath;
  }

  return filePath.replace(`{${viewKey}}`, viewValue);
}

function onCopyComplete(copyOperation) {
  (0, _log.logDebug)("Copied %s", copyOperation.dest);
}

function onCopyError(copyOperation) {
  (0, _log.logError)(new Error(`Could not copy ${copyOperation.dest}`));
}
//# sourceMappingURL=copy.js.map